#
# spec file for package kicad
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# According to upstream, kicad 8.x.y can be used with the footprint and
# symbol libraries from version 8.0.0
%define compatversion 8.0.0
Name:           kicad
Version:        8.0.7
%define file_version 8.0.7
Release:        1.1.2.1.sr20241202
Summary:        EDA software suite for the creation of schematics and PCB
License:        AGPL-3.0-or-later AND GPL-3.0-or-later
Group:          Productivity/Scientific/Electronics
URL:            https://www.kicad.org
Source:         https://gitlab.com/kicad/code/kicad/-/archive/%{file_version}/kicad-%{file_version}.tar.bz2

BuildRequires:  cmake >= 3.16
BuildRequires:  fdupes
# Requires charconv from C++17
%if 0%{?suse_version} >= 1550
BuildRequires:  gcc-c++ >= 8
%else
BuildRequires:  gcc11-PIE
BuildRequires:  gcc11-c++ >= 8
%endif
BuildRequires:  gettext
BuildRequires:  glm-devel >= 0.9.8
BuildRequires:  libboost_filesystem-devel-impl
BuildRequires:  libboost_locale-devel-impl
BuildRequires:  libboost_system-devel-impl >= 1.71
BuildRequires:  libboost_test-devel-impl
BuildRequires:  libngspice-devel
BuildRequires:  memory-constraints
BuildRequires:  occt-devel
BuildRequires:  pkg-config
BuildRequires:  python3-pybind11-devel
BuildRequires:  python3-wxPython
BuildRequires:  swig >= 3
BuildRequires:  update-desktop-files
BuildRequires:  wxGTK3-devel >= 3.2.4
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgit2)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(odbc)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(python3) >= 3.6
BuildRequires:  pkgconfig(zlib)
# Fix directory owner
BuildRequires:  hicolor-icon-theme
# Test requirements
BuildRequires:  python3-pytest
BuildRequires:  python3-CairoSVG

# Dlopen'ed simulator library
Requires:       libngspice0
# The help function gives an error without the doc package
Recommends:     kicad-doc = %{version}
# You cannot build a schematic without symbols
Requires:       kicad-symbols = %{compatversion}
# You cannot create a pcb layout without footprints
Requires:       kicad-footprints = %{compatversion}
# KiCad functions without these packages
Recommends:     kicad-packages3D = %{compatversion}
Recommends:     kicad-templates = %{compatversion}
Recommends:     python3-wxPython
Obsoletes:      kicad = 20140120
Provides:       kicad = %{compatversion}
# Test suite fails, 32 bit archs no longer supported
ExcludeArch:    %{arm}

%description
KiCad is an open source (GPL) software for the creation of electronic
schematic diagrams and printed circuit with up to 32 copper layers and
additional technical layers.

KiCad includes a project manager and four main independent software tools:
- Eeschema: schematic editor.
- Pcbnew: printed circuit board editor.
- Gerbview: GERBER file viewer (photoplotter documents).
- Cvpcb: footprint selector for components association.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch
# Per lang split packages from old kicad-i18n
Conflicts:      kicad-lang-bg < 6.0.0
Conflicts:      kicad-lang-ca < 6.0.0
Conflicts:      kicad-lang-cs < 6.0.0
Conflicts:      kicad-lang-de < 6.0.0
Conflicts:      kicad-lang-el < 6.0.0
Conflicts:      kicad-lang-en < 6.0.0
Conflicts:      kicad-lang-es < 6.0.0
Conflicts:      kicad-lang-fi < 6.0.0
Conflicts:      kicad-lang-fr < 6.0.0
Conflicts:      kicad-lang-hu < 6.0.0
Conflicts:      kicad-lang-it < 6.0.0
Conflicts:      kicad-lang-ja < 6.0.0
Conflicts:      kicad-lang-ko < 6.0.0
Conflicts:      kicad-lang-lt < 6.0.0
Conflicts:      kicad-lang-nl < 6.0.0
Conflicts:      kicad-lang-pl < 6.0.0
Conflicts:      kicad-lang-pt < 6.0.0
Conflicts:      kicad-lang-ru < 6.0.0
Conflicts:      kicad-lang-sk < 6.0.0
Conflicts:      kicad-lang-sl < 6.0.0
Conflicts:      kicad-lang-sv < 6.0.0
Conflicts:      kicad-lang-zh_CN < 6.0.0
Conflicts:      kicad-lang-zh_TW < 6.0.0

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup -p1 -n kicad-%{file_version}
%if 0%{?suse_version} < 1550
sed -i -e '/cmake_minimum_required/ s/3.21/3.16/' CMakeLists.txt
sed -i -e '/SWIG/ s/4.0/3.0/' CMakeLists.txt
sed -i -e '/SWIG_OPTS/ { s/ -O/ -py3/ ; s/ -fastdispatch//}' pcbnew/CMakeLists.txt
%endif

%build
%if 0%{?suse_version} < 1550
export CXX=g++-11 CC=gcc-11
%endif
%limit_build -m 1500
%cmake \
    -DCMAKE_SKIP_RPATH:BOOL=OFF \
    -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
    -DCMAKE_EXE_LINKER_FLAGS="-Wl,--as-needed -Wl,--no-undefined -Wl,-z,now -pie" \
    -DKICAD_DOCS:PATH=%{_docdir}/kicad \
    -DPYTHON_SITE_PACKAGE_PATH=%{python3_sitearch} \
    -DKICAD_BUILD_I18N=ON \
    -DKICAD_I18N_UNIX_STRICT_PATH:BOOL=ON \
    -DKICAD_SCRIPTING_WXPYTHON=ON \
    -DKICAD_USE_OCC:BOOL=ON \
    -DKICAD_PCM=ON \
    -DKICAD_SPICE=ON

%cmake_build

%install
%cmake_install

%if 0%{?suse_version} < 1550
%suse_update_desktop_file -r org.kicad.bitmap2component "Education;Engineering"
%suse_update_desktop_file -r org.kicad.eeschema "Education;Engineering"
%suse_update_desktop_file -r org.kicad.gerbview "Education;Engineering"
%suse_update_desktop_file -r org.kicad.kicad "Education;Engineering"
%suse_update_desktop_file -r org.kicad.pcbcalculator "Education;Engineering"
%suse_update_desktop_file -r org.kicad.pcbnew "Education;Engineering"
%endif

# Remove development symlinks, pointless without any headers etc.
rm %{buildroot}%{_libdir}/libki{cad_3dsg,common,gal}.so

# https://gitlab.com/kicad/code/kicad/-/issues/9944
find %{buildroot}%{_libdir} -iname \*.a -print -delete

# Fix executable bits for scripts executed directly from kicad
chmod -x %{buildroot}%{_datadir}/kicad/scripting/*/*.py

%fdupes %{buildroot}%{_datadir}/kicad
%fdupes %{buildroot}%{_datadir}/icons/hicolor

%find_lang %{name}

%check
./build/kicad/kicad-cli version --format about
%ctest --exclude-regex 'qa_spice|qa_cli|qa_common|qa_pcbnew'

%ifnarch %{ix86}
%ctest --tests-regex 'qa_spice|qa_cli|qa_common'
# Occasionally fails
%ctest --repeat until-fail:5 --tests-regex 'qa_pcbnew'
%endif

%ifarch %{ix86}
# common fails during a WX color conversion, 0xb2 != 0xb3 -> minor, ignore
# eeschema: https://gitlab.com/kicad/code/kicad/-/issues/10149
# pcbnew fails during Eagle import, e.g. stroke width 14999 != 15000 -> minor
%ctest --tests-regex 'qa_spice' || true
%ctest --tests-regex 'qa_cli|qa_common|qa_pcbnew' || true
%endif

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc README.md
%license LICENSE.*
%{_bindir}/*
%{_libdir}/kicad/
%{_libdir}/libki*.so.*
%{_datadir}/kicad/
%{python3_sitearch}/*
%{_datadir}/metainfo/org.kicad.kicad.metainfo.xml
%{_datadir}/applications/*.desktop
%{_datadir}/mime/packages/kicad-*.xml
%{_datadir}/icons/hicolor/*/mimetypes/application-x-*
%{_datadir}/icons/hicolor/*/apps/*.*

%files lang -f %{name}.lang

%changelog
* Wed Dec  4 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 8.0.7:
  See https://www.kicad.org/blog/2024/12/KiCad-8.0.7-Release/ for details
- Drop upstream patches:
  * fix_libgit2_API_breakage.patch
  * fix_libgit2_API_breakage_again.patch
* Sun Nov 10 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with libgit2 >= 1.8.4, the previous API break was
  re-reverted, add:
  * fix_libgit2_API_breakage_again.patch
* Tue Oct 29 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with libgit2 >= 1.8.3, a previous API break was
  reverted, add:
  * fix_libgit2_API_breakage.patch
* Tue Oct 22 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 8.0.6:
  See https://www.kicad.org/blog/2024/10/KiCad-8.0.6-Release/ for details
- Drop upstream patches:
  * fix_boost_1_86_compat.patch
  * fix_bad_cast_boost_1_86.patch
  * fix_boost_1_86_sha1_detail.patch
* Wed Sep 18 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.5:
  See https://www.kicad.org/blog/2024/09/KiCad-8.0.5-Release/ for details
- Fix compilation with Boost 1.86:
  * fix_boost_1_86_compat.patch
  * fix_bad_cast_boost_1_86.patch
  * fix_boost_1_86_sha1_detail.patch
* Mon Jul 29 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.4:
  See https://www.kicad.org/blog/2024/07/KiCad-8.0.4-Release/ for details
* Wed Jun 12 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.3:
  See https://www.kicad.org/blog/2024/06/KiCad-8.0.3-Release/ for details
* Mon May  6 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.2:
  See https://www.kicad.org/blog/2024/04/KiCad-8.0.2-Release/ for details
- Drop upstream patches:
  * fix_zone_fill_race.patch
  * 0001-Fix-triangulationValid-check-race-for-zone-fill.patch
  * libgit2-1.8.0-compatibility.patch
* Wed Mar 27 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with libgit2 >= 1.8.0, add
  libgit2-1.8.0-compatibility.patch
* Fri Mar 15 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.1:
  See https://www.kicad.org/blog/2024/03/KiCad-8.0.1-Release/ for details
- Fix some race condition, causing e.g. fails in qa_pcbnew:
  * fix_zone_fill_race.patch
  * 0001-Fix-triangulationValid-check-race-for-zone-fill.patch
* Sun Feb 25 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 8.0.0:
  See https://www.kicad.org/blog/2024/02/Version-8.0.0-Released/ for details
* Mon Jan  1 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.10:
  See https://www.kicad.org/blog/2023/12/KiCad-7.0.10-Release/ for details
* Thu Dec  7 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.9:
  See https://www.kicad.org/blog/2023/11/KiCad-7.0.9-Release/ for details
- update to 7.0.8:
  See https://www.kicad.org/blog/2023/09/KiCad-7.0.8-Release/ for details
* Mon Sep 11 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.7:
  See https://www.kicad.org/blog/2023/08/KiCad-7.0.7-Release/ for details.
* Mon Aug 14 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.6:
  See https://www.kicad.org/blog/2023/07/KiCad-7.0.6-Release/ for details.
- Ignore minor test failures on i586
* Sat Jun  3 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.5:
  See https://www.kicad.org/blog/2023/05/KiCad-7.0.5-Release/ for details.
* Tue Apr 25 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.2:
  See https://www.kicad.org/blog/2023/04/KiCad-7.0.2-Release/ for details.
- Reduce build parallelism to avoid occasional OOM errors.
- Disable qa_eeschema unit test on aarch64.
* Sat Mar 11 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.1:
  See https://www.kicad.org/blog/2023/03/KiCad-7.0.1-Release/ for details.
* Tue Feb 14 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 7.0.0:
  See https://www.kicad.org/blog/2023/02/KiCad-7.0.0-Release/ for details.
- Drop obsolete
  0001-Use-library-target-install-for-python-module-to-fix-.patch
- Adjust memory _constraints, add memoryperjob
* Thu Jan 26 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 6.0.11:
  See https://www.kicad.org/blog/2023/01/KiCad-6.0.11-Release/ for details.
* Thu Dec 29 2022 Dirk Müller <dmueller@suse.com>
- update to version 6.0.10:
  See https://www.kicad.org/blog/2022/12/KiCad-6.0.10-Release/ for details.
* Sat Nov  5 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.9
  See https://www.kicad.org/blog/2022/10/KiCad-6.0.9-Release/ for details.
* Fri Oct 28 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.8
  See https://www.kicad.org/blog/2022/09/KiCad-6.0.8-Release/ for details.
* Sun Aug 28 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.7
  See https://www.kicad.org/blog/2022/07/KiCad-6.0.7-Release/ for details.
* Tue Jun 21 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.6
  See https://www.kicad.org/blog/2022/06/KiCad-6.0.6-Release/ for details.
* Fri May 13 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.5
  See https://www.kicad.org/blog/2022/05/KiCad-6.0.5-Release/ for details.
- Use Boost >= 1.71 on Leap.
* Sat Mar 19 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.4
  See https://www.kicad.org/blog/2022/03/KiCad-6.0.4-Release/ for details.
* Fri Feb 11 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.2
  See https://www.kicad.org/blog/2022/02/KiCad-6.0.2-Release/ for details.
* Sat Feb  5 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix suse_update_desktop_file invocation on Leap (missing new
  "org.kicad." prefix for desktop file names).
* Tue Jan 25 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.1
  See https://www.kicad.org/blog/2022/01/KiCad-6.0.1-Release/ for details.
* Sat Dec 25 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 6.0.0
  See https://www.kicad.org/blog/2021/12/KiCad-6.0.0-Release/ for details.
- Drop no longer necessary kicad-suse-help-path.patch
- Add 0001-Use-library-target-install-for-python-module-to-fix-.patch
- Adjust disk constraints (now 11G)
* Thu Nov 18 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.12
  See https://kicad.org/blog/2021/11/KiCad-5.1.12-Release/ for details.
* Sat Oct 30 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.11
  See https://kicad.org/blog/2021/11/KiCad-5.1.11-Release/ for details.
- Replace references to old domain (hijacked) with kicad.org
  https://www.kicad.org/blog/2021/10/Avoid-links-to-former-kicad-domain/
* Sun Apr 25 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.10
  See https://kicad.org/blog/2021/05/KiCad-5.1.10-Release/ for details.
* Wed Dec 30 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.9
  See https://kicad.org/blog/2020/12/KiCad-5.1.9-Release/ for details.
- On TW, disable XDG category mangling, keep new upstream category
  Science;Electronics.
* Fri Nov  6 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.8
  See https://kicad.org/blog/2020/11/KiCad-5.1.8-Release/ for details.
* Mon Sep 28 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.7, no changelog provided
- Drop now upstream
  0001-Remove-creation-on-the-fly-of-wxPaintEvent-instances.patch
* Fri Jul 31 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.6
  See http://kicad-pcb.org/blog/2020/05/KiCad-5.1.6-Release/ for details.
- Switch from OCE to OCC OpenCascade implementation, as recommended
  by upstream (FreeCAD uses OCC now as well).
- Fix compilation with latest wxWidgets:
  0001-Remove-creation-on-the-fly-of-wxPaintEvent-instances.patch
- Drop kicad-user-library.patch, only relevant for KiCad 4.0
  footprint libraries.
* Mon Nov 18 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.5
  See http://kicad-pcb.org/blog/2019/11/KiCad-5.1.5-Release/ for details.
* Wed Aug  7 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to minor release 5.1.4
  See http://kicad-pcb.org/blog/2019/08/KiCad-5.1.4-Release/ for details.
* Thu Apr 25 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to minor release 5.1.2
  This version contains critical bugfixes and minor improvements.
  See http://kicad-pcb.org/blog/2019/04/KiCad-5.1.2-Release/ for details.
* Mon Apr 15 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to minor release 5.1.1
  (Withdrawn due to a critical bug in netlist generation)
* Fri Apr 12 2019 normand@linux.vnet.ibm.com
- Enable build for PowerPC, supported since KiCad 5.1.0.
  Also fixes a recurrent rebuild of kicad-doc, due to it having
  an unresolvable dependency on kicad.
* Mon Mar 11 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to minor release 5.1.0
  This version contains critical bugfixes and minor improvements.
  See http://kicad-pcb.org/blog/2019/03/KiCad-5.1.0-Release/ for details.
- Remove obsolete kicad-library-repos-install.patch
- Remove upstream 0001-Use-absolute-path-CMAKE_INSTALL_FULL_LIBDIR-for-3d-v.patch
* Tue Feb 19 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Revert broken change for symbol etc. library versions, there is nothing
  disallowing recent packages.
- Exclude PPC, not yet supported
* Tue Feb 19 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Set disk size constraint to avoid build failure seen on aarch64
* Wed Dec 12 2018 davejplater@gmail.com
- Allow up to date versions of symbol, footprint, template and 3D
  packages.
* Thu Dec  6 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to bugfix release 5.0.2
  This version contains critical bugfixes and minor improvements.
  See http://kicad-pcb.org/blog/2018/12/KiCad-5.0.2-Release/ for details.
- Drop upstreamed 0001-Use-fixed-version-for-libngspice.so.0.patch
- Drop COPYRIGHT/LICENSE.AGPLv3, both files are included in the tarball now.
* Fri Oct 26 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add Requires: libngspice0
- Fix name for dlopen'ed libngspice.so.0
  Add 0001-Use-fixed-version-for-libngspice.so.0.patch
* Thu Oct 18 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to bugfix release 5.0.1
  This version contains critical bugfixes and minor improvements.
  See http://kicad-pcb.org/blog/2018/10/KiCad-5.0.1-Release/ for details.
- Do proper fix for 3d plugindir, use absolute LIBDIR instead of
  deriving it from BINDIR:
  Add 0001-Use-absolute-path-CMAKE_INSTALL_FULL_LIBDIR-for-3d-v.patch
- Drop upstream kicad-fix-boost168-build.patch.
- Add Recommends: for new kicad-templates package
* Wed Oct 10 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Correct license to GPL-3.0-or-later AND AGPL-3.0-or-later
  Add LICENSE.AGPLv3 for some included third party code
* Fri Oct  5 2018 davejplater@gmail.com
- Add build option to fix boo#1107776 kicad: 3D models do not work
* Mon Oct  1 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Correct license, KiCad 5.0 no longer is GPL-2.0. Stop distributing
  a wrong license file inside the package.
* Sat Sep 29 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Enable spice simulator support
- Install python bindings in python_sitearch
- Deduplicate pcbnew python binary module
- Adapt libboost_* BuildRequires for current distribution versions
- Remove obsolete CMAKE options
- Set various pathes using using CMAKE options instead of patching
  files.
* Tue Sep 18 2018 davejplater@gmail.com
- Fix build against boost-1.68 with kicad-fix-boost168-build.patch.
* Wed Jul 25 2018 davejplater@gmail.com
- Update to new release version 5.0.0
- Removed incorporated patches:
  kicad-4.0.7-remove-internal-CheckCXXSymbolExists.patch,
  kicad-boost-1_61-boost-context-changes.patch and
  kicad-set-cxx-version.patch.
- Rebased kicad-user-library.patch.
- Upstream changes:
  This version has many new features and improvments over 4.0.7.
  See kicad-pcb.org/blog/2018/07/KiCad-5--a-new-generation/ for
  all the details.
* Fri May 25 2018 antoine.belvire@opensuse.org
- Fix build with CMake 3.11 (deb#897100):
  * Add kicad-4.0.7-remove-internal-CheckCXXSymbolExists.patch,
    picked from upstream.
- Use %%license for license file instead of %%doc (boo#1082318).
- Use SPDX 3 license identifier.
- Don't call empty macros in %%post and %%postun.
* Mon Sep  4 2017 davejplater@gmail.com
- Update to version 4.0.7.
- Build with fPIE.
- Rebased kicad-set-cxx-version.patch.
- Upstream changes:
  * Bugs Fixed:
  Fix broken links and add correct links to about dialog.
  Eeschema: highlight the first choice in rescue dialog.
  Eeschema: fix zone properties dialog level setting tooltip.
  Pcbnew: fix segfault when appending a board in GAL mode.
  Remove some useless or incorrect asserts in plot functions.
  Pcbnew: continue loading footprints after first failure.
  Eeschema: don’t apply last line width to text thickness in
  symbol library editor.
  Pcbnew: add option to plot DXF lines in outline mode.
  Pcbnew: add option to plot DXF editable text.
  Pcbnew: fix crash when dragging a track.
  Fix crash when dragging a track.
  Remove leading/trailing white space error message from field
  validator.
  * Other changes:
  Pcbnew: fix bug loading board files written when layers could
  have numeric names.
  Pcbnew: prevent segfault when outline has no vertices reading
  P-CAD file.
  Pcbnew: fix tooltip error in copper zones dialog.
  Eeschema: move BOM scripts so they are installed correctly.
  Apply changes from master to GOST page layouts.
  Save text thickness in worksheet editor.
  Fix default line widths for non-mm units in DXF import.
  Better error messages when throwing an I/O error or parse error.
  Cvpcb: fix incorrect assignments when using .equ files and
  automatic association.
  Fix possible crash and issues when a incorrect fp lib table is
  loaded.
  Fix crash when writing zip archive file to folder that is not
  writeable.
  Fix issues in plot functions when used from python scripts.
* Wed Mar 22 2017 xxxxxmichl@googlemail.com
- Update to version 4.0.6
- Upstream changes
  * Library changes:
  You may need to update your footprint library table in pcbnew,
  because some footprint libraries have been renamed as follows:
    Buttons_Switches_ThroughHole.pretty ->
    Buttons_Switches_THT.pretty
    Capacitors_ThroughHole.pretty -> Capacitors_THT.pretty
    Connect.pretty -> Connectors.pretty
    Diodes_ThroughHole.pretty -> Diodes_THT.pretty
    Display.pretty -> Displays.pretty
    Relays_ThroughHole.pretty -> Relays_THT.pretty
    Resistors_ThroughHole.pretty -> Resistors_THT.pretty
    Sockets_BNC.pretty -> Connectors_TE-Connectivity.pretty
    Sockets_Mini-Universal.pretty ->
    Connectors_Mini-Universal.pretty
    Sockets_WAGO734.pretty -> Connectors_WAGO.pretty
    Terminal_Blocks.pretty -> Connectors_Terminal_Blocks.pretty
  * Bugs fixed:
    Pcbnew: fix an issue where path separators are not translated
    from \ in Windows to / on Unix.
    Pcbnew: do not use default board solder mask clearance in
    footprint editor.
    Pcbnew: fix a potential incompatibility (due to an old bug)
    with files which could be created by some recent Pcbnew versions.
    Eeschema: fix rotate bug in symbol library editor.
  Changes:
    Replace avhttp with libcurl.
    Pcbnew: fix a potential bug where a GAL canvas method was
    called from the legacy canvas.
    Eeschema: reorder toolbar slightly.
  * The KiCad development team hopes you enjoy this latest stable
  release of KiCad.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Tue Jan 10 2017 davejplater@gmail.com
- Update to version 4.0.5
- The KiCad project is pleased to announce that it is the first
  electronic development application to fully support the Gerber X2
  extensions.
- Upstream changes
  * Bugs Fixed:
  KiCad: fix crash when attempting to view ERC log with text
  editor.
  Pcbnew: fix several auto save file issues.
  Eeschema: fix assertion on delete node hot key while busy.
  Pcbnew: fix drill file naming issue.
  CvPcb: remove broken footprint documentation feature.
  Footprint editor: fix transform for incorrect mirroring of pads
  (only effects pads with offset).
  Pcbnew: prevent drawing tracks on non copper layers in GAL
  canvas.
  Fix crash when BOARD members are changed and PNS is active.
  Fix wrong CSV BOM format using bom2csv.xsl script with custom
  entries.
  * Changes:
  Fixed a crash when drawing a single point polyline.
  Gerbview: make print dialog display graphic layers list on some
  windows managers like Unity.
  Pcbnew: fix epic footprint editor DXF import fail.
  Fixed a crash when a negative (although invalid) net code
  occurs in legacy plugin.
  Pcbnew: prevent reversal of pad loading order when loading board.
  Fix incorrect indentation which generates compiler warnings.
  Pcbnew: make polygons strictly simple before fracturing them
  in zone fill calculations.
  Fix off-by-one in saving bitmaps.
  Version string improvements.
  * The KiCad development team hopes you enjoy this latest stable
  release of KiCad.
* Tue Nov 22 2016 adam.majer@suse.de
- No longer depend on boost_1_58_0 explicitly as it now provides
  boost-devel with correct version numbers.
* Mon Sep 12 2016 davejplater@gmail.com
- Update to version 4.0.4
  * bugfix release
- Ran dos2unix and rebased
  kicad-boost-1_61-boost-context-changes.patch
- Rebased kicad-set-cxx-version.patch,kicad-suse-help-path.patch,
  and kicad-user-library.patch.
* Sat Aug 27 2016 stefan.bruens@rwth-aachen.de
- Pull some coroutine changes from kicad master, to fix build
  with boost 1.61 (boo#994383). Use on Leap and TW.
  * Add kicad-boost-1_61-boost-context-changes.patch
- Set C++ version to C++11, required by boost patch
  * Add kicad-set-cxx-version.patch
* Mon Aug  8 2016 dmitry_r@opensuse.org
- Update to version 4.0.3
  * Bugfix release
  * Drop obsolete kicad-swig-3.0.10.patch
* Thu Jul  7 2016 dmitry_r@opensuse.org
- Fix broken swig import script when using swig >= 3.0.10
  * kicad-swig-3.0.10.patch
* Fri May  6 2016 davejplater@gmail.com
- Added kicad-suse-help-path.patch to enable help in kicad.
- Added post and postun macros to allow proper integration with
  various gui systems.
* Mon Mar 21 2016 dmitry_r@opensuse.org
- Update to version 4.0.2
  * Bugfix release
* Wed Dec  9 2015 dmitry_r@opensuse.org
- Update to version 4.0.1
* Sun Dec  6 2015 dvaleev@suse.com
- Increase diskspace constraints to 8GB
* Mon Nov 30 2015 dmitry_r@opensuse.org
- Update to version 4.0.0
  Changes from previous stable release:
  * New graphics rendering backend GAL (OpenGL and Cairo)
  * New s-expression based pcb format (.kicad_pcb)
  * New footprint library format (.pretty folder with .kicad_mod footprints)
  * Updated footprint editor
  * More advanced footprint manager concept called footprint library table (fp-lib-table)
  * Ability to download footprints on the fly from git repositories
  * Official libraries are now stored on github and regularly updated
  * Awesome/Advanced Push and Shove (PnS) router (only usable with GAL renderer)
  * Interactive differential trace routing and tuning
  * Interactive trace length tuning
  * Much more realistic 3D board rendering
  * Intelligent library search with preview in Eeschema
  * Initial Python api for Pcbnew
* Mon Nov  9 2015 dmitry_r@opensuse.org
- Update to version 4.0.0-rc2
* Wed Sep 30 2015 dmitry_r@opensuse.org
- Set minimal memory size for building: 3500 Mb
* Sun Sep 13 2015 dmitry_r@opensuse.org
- Update to version 4.0.0-rc1
  * Drop kicad-gost package
  * Drop pre_checkin.sh
  * Drop container_fwd.hpp.patch
  * Drop kikad-no-templates-install.patch
- Change license to "GPL-2.0+ and GPL-3.0+" due to source code changes
- Use user library instead of system
  * kicad-user-library.patch
- Replase kicad-libraries package with kicad-library-install.sh
  script for creation offline library copy.
  * kicad-library-repos-install.patch
* Tue Jun 30 2015 tjcw@physics.org
- Mend build breakage by using 'system' list class rather than kicad/boost one
  * container_fwd.hpp.patch
* Wed Mar 25 2015 jengelh@inai.de
- Do not conflict with self-provides
* Tue Feb 25 2014 dmitry_r@opensuse.org
- Update to version 20140120
  * Bug fixes
* Wed Aug  7 2013 dmitry_r@opensuse.org
- Removed templates to avoid conflict with kicad-library package
  * kikad-no-templates-install.patch
- Removed obsolete kicad-2012.01.19-build-with-old-wxwidgets.patch
* Wed Jul 17 2013 dmitry_r@opensuse.org
- Update to version 20130707
  * no changelog available
  * removed obsolete kicad-2012.01.19-gcc-4.7.patch
* Thu Jun 27 2013 dmitry_r@opensuse.org
- Change package license to GPL-2.0+ [bnc#796377]
* Mon Apr  8 2013 werner.ho@gmx.de
- new version 20130330
- removed version patch
* Wed Jan 23 2013 dmitry_r@opensuse.org
- Update to version 20120521
  * various bugfixes, no detailed changelog available
- Change package license to GPL-3.0 [bnc#796377]
- Build with Unicode support
- Add switcher for build with GOST support
- Fix displayed version
  * kicad-version.patch
* Tue Aug 28 2012 scorot@free.fr
- fix build with old wxWindow on SLE 11
* Wed Jun 27 2012 scorot@free.fr
- add patch from debian to fix build with gcc-4.7
* Sat Feb 11 2012 werner.ho@gmx.de
- new version 2012-01-19
* Tue Jan 17 2012 werner.ho@gmx.de
- new version 2011-12-28
* Sun Aug 21 2011 werner.ho@gmx.de
- new version 2011-07-08
* Fri May 27 2011 werner.ho@gmx.de
- new version 2011-04-29
* Mon Mar 28 2011 stefan.bruens@rwth-aachen.de
- explicit request for DOUBLEBUFFER and DEPTH>=16
  fixes SwapBuffer() crash on Intel and Radeon GPUs
* Tue Mar 15 2011 werner.ho@gmx.de
- build fix for openSUSE 11.4
* Sun Nov  7 2010 werner.ho@gmx.de
- added l10n files and patch fixes bug [#650383]
* Fri Jul 23 2010 mhopf@novell.com
- Update to 2010-05-05-stable
* Mon Apr 12 2010 mhopf@novell.com
- Make it build with older wxGTK (wxAuiToolBar)
* Mon Apr 12 2010 mhopf@novell.com
- Update to 2010-04-06-SVN2508
  Currently only builds on 11.2
* Wed Jun 17 2009 Werner Hoch <werner.ho@gmx.de> - 2009.02.06
- new version 2009.02.06
* Sat Dec 20 2008 Werner Hoch <werner.ho@gmx.de> - 2008.08.25
- build fix for openSUSE 11.1
- added freeglut-devel and update_desktop_file
- directory fixes
* Sat Oct  4 2008 Werner Hoch <werner.ho@gmx.de> - 2008.08.25
- new version 2008.08.25
* Tue Mar 25 2008 Werner Hoch <werner.ho@gmx.de>
- new version 2008.03.20
* Tue Dec 25 2007 Werner Hoch <werner.ho@gmx.de>
- adapted spec file from kicad-2007.07.09-2.fc8.src.rpm
- removed french project descriptions
- use cmake build process
- new version 2007.11.29
  Mon Oct 15 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.07.09-2
- Update desktop file
  Thu Oct 04 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.07.09-1
- New upstream version
- Merge previous patches
- Remove X-Fedora, Electronics and Engineering categories
- Update desktop file
  Mon Aug 27 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.01.15-4
- License tag clarification
  Thu Aug 23 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.01.15-3
- Rebuild
  Wed Feb 14 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.01.15-2
- Fix desktop entry. Fix #228598
  Thu Feb  8 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.01.15-1
- New upstream version
  Thu Feb  8 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.08.28-4
- Add patch to build with RPM_OPT_FLAGS and remove -s from LDFLAGS
  Contribution of Ville Skyttä <ville[DOT]skytta[AT]iki[DOT]fi>
  Fix #227757
- Fix typo in french summary
* Thu Dec 28 2006 Jason L Tibbitts III <tibbs@math.uh.edu> 2006.08.28-3
- Rebuild with wxGTK 2.8.
* Thu Oct  5 2006 Christian Iseli <Christian.Iseli@licr.org> 2006.08.28-2
- rebuilt for unwind info generation, broken in gcc-4.1.1-21
  Fri Sep 22 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.08.28-1
- New upstream version
- Use macro style instead of variable style
- Install missing modules. Fix #206602
  Fri Sep  1 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-6
- FE6 rebuild
  Mon Jul 10 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-5
- Removing backup files is no more needed.
  Mon Jul 10 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-4
- Remove BR libGLU-devel that is no more needed (bug #197501 is closed)
- Fix files permissions.
  Mon Jul  3 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-3
- s/mesa-libGLU-devel/libGLU-devel/
  Mon Jul  3 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-2
- BR mesa-libGLU-devel
  Wed Jun 28 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-1
- New upstream version
  Tue Jun 13 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.04.24-5
- Change name
- Use %%%%{_docdir} instead of %%%%{_datadir}/doc
- Use %%%%find_lang
- Update desktop database
- Convert MSDOS EOL to Unix EOL
- Remove BR utrac
  Mon Jun 12 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006-04-24-0-4
- Patch to suppress extra qualification compile time error on FC5
- BR utrac to convert MSDOS files before applying patch
  This will be remove for the next upstream version.
  Tue May 23 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006-04-24-0-3
- Install help in /usr/share/doc/kicad/ as the path is hardcoded
  in gestfich.cpp
- Add desktop file
  Mon May 22 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006-04-24-0-2
- Add a second tarball that contains many things that are not included in
  the upstream source tarball such components and footprints librairies,
  help, localisation, etc.
  Sun May 21 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006-04-24-0-1
- Initial Fedora RPM
